pub enum ComponentTypeRef {
Module(u32),
Func(u32),
Value(ComponentValType),
Type(TypeBounds, u32),
Instance(u32),
Component(u32),
}Expand description
Represents a reference to a component type.
Variants
Module(u32)
The reference is to a core module type.
The index is expected to be core type index to a core module type.
Func(u32)
The reference is to a function type.
The index is expected to be a type index to a function type.
Value(ComponentValType)
The reference is to a value type.
Type(TypeBounds, u32)
The reference is to a bounded type.
The index is expected to be a type index.
Instance(u32)
The reference is to an instance type.
The index is a type index to an instance type.
Component(u32)
The reference is to a component type.
The index is a type index to a component type.
Implementations
sourceimpl ComponentTypeRef
impl ComponentTypeRef
sourcepub fn kind(&self) -> ComponentExternalKind
pub fn kind(&self) -> ComponentExternalKind
Returns the corresponding ComponentExternalKind for this reference.